=========================
 Invenio Theme v1.0.0b4
=========================

Invenio Theme v1.0.0b4 was released on August 10, 2017.

About
-----

Invenio standard theme.

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-theme==1.0.0b4

Documentation
-------------

   https://invenio-theme.readthedocs.io/

Happy hacking and thanks for flying Invenio Theme.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-theme
|   URL: http://inveniosoftware.org
